@@ -2,10 +2,10 @@ from concurrent import futures
 
 import grpc
 
-from grebble_flow.grpc.generated.internal.v1 import processor_pb2_grpc, app_pb2_grpc
-from grebble_flow.grpc.service.app import AppService
+from grebble_flow.protobuf.protobuf import processor_pb2_grpc, app_pb2_grpc
+from grebble_flow.protobuf.service.app import AppService
 
-from grebble_flow.grpc.service.processor import ProcessorService
+from grebble_flow.protobuf.service.processor import ProcessorService
 
 
 def start_server(port):
