@@ -1,6 +1,6 @@
 import json
 
-from grebble_flow.grpc.generated.internal.v1 import app_pb2_grpc
+from grebble_flow.protobuf.protobuf import app_pb2_grpc
 from grebble_flow.managment.info import generate_package_info
 
 
