@@ -1,6 +1,6 @@
 import json
 
-from grebble_flow.grpc.generated.internal.v1 import processor_pb2_grpc
+from grebble_flow.protobuf.protobuf import processor_pb2_grpc
 from grebble_flow.helpers.converter import grebble_converter
 from grebble_flow.managment.manager import FlowManager
 
