@@ -1,7 +1,7 @@
 import click
 import grpc
 
-from grebble_flow.grpc import manager
+from grebble_flow.protobuf import manager
 
 
 @click.group()
